/*
  DXC Framework (http://dx-competition.org/)
  Copyright 2008 David Garcia

  The DXC Framework is free software: you can redistribute it and/or modify it
  under the terms of the GNU Lesser General Public License as published by the
  Free Software Foundation, either version 3 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
  details.

  You should have received a copy of the GNU Lesser General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>
*/
#ifndef CANDIDATE_HPP
#define CANDIDATE_HPP

#include <iostream>
#include <string>
#include <map>

#include <DxcDefs.hpp>
#include <DataTypes/Fault.hpp>

namespace Dxc
{
/**
 * @brief Maps a set of component IDs to (hypothesized) faulty states.
 */
class DXCAPI_EXPORT Candidate
{
public:
    Candidate();
    Candidate(const FaultSet& faults, double optionalWeight = -1);

    /**
     * Returns the set of hypothesized faults.
     */
    FaultSet* getFaults();

    /**
     * Sets the fault set to specified hypothesized faults.
     */
    void setFaults(const FaultSet&);

    /**
     * Returns the weight of this candidate relative to others in the
     * diagnosis.
     *
     * Weights in a candidate set are normalized upon creation of
     * DiagnosisData, such that they add up to 1.
     */
    double getWeight() const;

    void setWeight(double weight);

    bool operator<(const Candidate&) const;
    std::ostream &put(std::ostream &) const;

private:
    FaultSet faults_;
    double weight_;
};


/**
 * @brief Candidate set typedef
 */
typedef DXCAPI_EXPORT std::set<Candidate> cSet;

/**
 * @brief A set of Candidates.
 */
class DXCAPI_EXPORT CandidateSet : public cSet
{
public:
    std::ostream &put(std::ostream &) const;
};

}

std::ostream DXCAPI_EXPORT & operator << (std::ostream &, const Dxc::Candidate&);
std::ostream DXCAPI_EXPORT & operator << (std::ostream &, const Dxc::CandidateSet&);

#endif
