/*
  DXC Framework (http://dx-competition.org/)
  Copyright 2008 David Garcia

  The DXC Framework is free software: you can redistribute it and/or modify it
  under the terms of the GNU Lesser General Public License as published by the
  Free Software Foundation, either version 3 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
  details.

  You should have received a copy of the GNU Lesser General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>
*/
#include <DataTypes/RecoveryData.hpp>

using namespace std;
using namespace Dxc;

RecoveryData::RecoveryData(Timestamp timestamp,
                           const FaultSet& fs,
                           const CommandSet& commands,
                           double cost,
                           const std::string& notes):
    DxcData(timestamp),
    faults_(fs),
    commands_(commands),
    cost_(cost),
    notes_(notes)
{
}

RecoveryData::RecoveryData(const FaultSet& fs,
                           const CommandSet& commands,
                           double cost,
                           const std::string& notes):
    DxcData(),
    faults_(fs),
    commands_(commands),
    cost_(cost),
    notes_(notes)
{
}

const FaultSet* RecoveryData::getFaults() const
{
    return &faults_;
}

const CommandSet* RecoveryData::getCommands() const
{
    return &commands_;
}

double RecoveryData::getCost() const
{
    return cost_;
}

string RecoveryData::getNotes() const
{
    return notes_;
}

RecoveryData* RecoveryData::clone() const
{
    return new RecoveryData(*this);
}

ostream &RecoveryData::put(ostream &out) const
{
    out << "recoveryInfo @" << this->getTimeStamp();
    if (this->getSource() != "")
        out << " <" << this->getSource() << ">";

    out << " faults = " << faults_ << ",";
    out << " commands = ";

    commands_.put(out);

    out << ", "<< " cost = " << cost_;
    out << ", notes = '" << notes_ << "'";

    out << ";" << endl;

    return out;
}
