/*
  DXC Framework (http://dx-competition.org/)
  Copyright 2008 David Garcia

  The DXC Framework is free software: you can redistribute it and/or modify it
  under the terms of the GNU Lesser General Public License as published by the
  Free Software Foundation, either version 3 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
  details.

  You should have received a copy of the GNU Lesser General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>
*/
#include <DataTypes/ScenarioStatusData.hpp>

using namespace Dxc;
using namespace std;

const string ScenarioStatusData::SDS_AWAITING_DA = "SDS_AWAITING_DA";
const string ScenarioStatusData::DA_READY = "DA_READY";
const string ScenarioStatusData::SR_READY = "SR_READY";
const string ScenarioStatusData::STARTED = "SCENARIO_STARTED";
const string ScenarioStatusData::SDS_ENDED = "SCENARIO_ENDED";
const string ScenarioStatusData::DA_ENDED = "DA_TERMINATED";
const string ScenarioStatusData::UNKNOWN = "UNKNOWN";

ScenarioStatusData::ScenarioStatusData(Timestamp timestamp, const std::string& status)
    : DxcData(timestamp)
{
    if (status == SDS_AWAITING_DA ||
            status == DA_READY ||
            status == SR_READY ||
            status == STARTED ||
            status == SDS_ENDED ||
            status == DA_ENDED)
    {
        status_ = status;
    }
    else
    {
        status_ = UNKNOWN;
    }
}

ScenarioStatusData::ScenarioStatusData(const std::string& status)
    : DxcData()
{
    if (status == SDS_AWAITING_DA ||
            status == DA_READY ||
            status == SR_READY ||
            status == STARTED ||
            status == SDS_ENDED ||
            status == DA_ENDED)
    {
        status_ = status;
    }
    else
    {
        status_ = UNKNOWN;
    }
}

string ScenarioStatusData::getStatus() const
{
    return status_;
}

ScenarioStatusData* ScenarioStatusData::clone() const
{
    return new ScenarioStatusData(*this);
}

ostream &ScenarioStatusData::put(ostream &out) const
{
    out << "scenarioStatus @" << this->getTimeStamp();
    if (this->getSource() != "")
        out << " <" << this->getSource() << ">";
    out << " " << status_ << ";" << endl;
    out.flush();
    return out;
}
