/*
  DXC Framework (http://dx-competition.org/)
  Copyright 2008 David Garcia

  The DXC Framework is free software: you can redistribute it and/or modify it
  under the terms of the GNU Lesser General Public License as published by the
  Free Software Foundation, either version 3 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
  details.

  You should have received a copy of the GNU Lesser General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>
*/
#ifndef MESSAGE_DRIVER
#define MESSAGE_DRIVER

#include <string>
#include <vector>
#include <deque>

#include <DxcDefs.hpp>
#include <DxcDataTypes.hpp>

#ifdef _WIN32
#include <Pthreads-w32/pthread.h>
#else
#include <pthread.h>
#endif

using namespace std;

namespace Dxc
{

class DXCAPI_EXPORT MessageDriver
{
public:
    MessageDriver();

public:
    bool parseStream(istream &, const string & = "stream input");
    bool parseString(const string &, const string & = "string stream");
    bool parseFile(const string &);

    void gotMessage(DxcData *);
    DxcData* getNextMessage();
    bool hasMessages();
    void setMessageHook(void (*)(DxcData *));

    void error(const class location &, const string &);
    void error(const string &);

public:
    class MessageScanner *lexer_;

    string streamName_;

private:
    bool traceScanning_;
    bool traceParsing_;

    deque<DxcData*> mQueue_;
    pthread_mutex_t mQueueMutex_;
    void (*messageHook_)(DxcData *);
};

}

#endif
