package org.dxc.api.datatypes;

/**
 * Maps a set of component IDs to (hypothesized) faulty states.
 */
public class Candidate {
    public Candidate(FaultSet faultSet, double optionalWeight) {
        this.faultSet = faultSet;
        this.weight = optionalWeight;
    }

    public Candidate(FaultSet faultSet) {
        this.faultSet = faultSet;
        this.weight = -1;
    }

    public Candidate() {
        this.faultSet = new FaultSet();
        this.weight = -1;
    }

    public boolean equals(Object o) {
        Candidate c = (Candidate) o;
        if (c == null)
            return false;

        if (c.faultSet.equals(faultSet) && c.weight == weight)
            return true;
        return false;
    }

    public int hashCode() {
        int hash = 7;
        hash = 31 * hash + (int) (weight * 100);
        hash = 31 * hash + (faultSet == null ? 0 : faultSet.hashCode());
        return hash;
    }

    /**
     * A map of component IDs to predicted fault mode IDs.
     */
    public FaultSet getFaultSet() {
        return faultSet;
    }

    public void setFaultSet(FaultSet f) {
        this.faultSet = f;
    }

    /**
     * Weight of this candidate relative to others in the diagnosis.
     * 
     * Weights in a candidate set are normalized upon creation of DiagnosisData,
     * such that they add up to 1.
     */
    public double getWeight() {
        return weight;
    }

    public void setWeight(double w) {
        this.weight = w;
    }

    public String toString() {
        return faultSet.toString() + " [weight = " + this.getWeight() + "]";
    }

    private FaultSet faultSet;
    private double weight;
}
