/*
  DXC Framework (http://dx-competition.org/)
  Copyright 2008 David Garcia
  
  The DXC Framework is free software: you can redistribute it and/or modify it 
  under the terms of the GNU Lesser General Public License as published by the 
  Free Software Foundation, either version 3 of the License, or (at your 
  option) any later version. 

  This program is distributed in the hope that it will be useful, but WITHOUT 
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
  FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more 
  details. 

  You should have received a copy of the GNU Lesser General Public License 
  along with this program. If not, see <http://www.gnu.org/licenses/> 
 */
package org.dxc.api.datatypes;

import java.io.OutputStream;
import java.io.PrintStream;
import java.util.Map;
import java.util.Iterator;

/**
 * Data structure for sensor data messages.
 */
public class SensorData extends DxcData {

    private StringValueMap sensors;

    /**
     * Constructor.
     * 
     * @param timestamp
     *            - message timestamp.
     * @param sensors
     *            - map containing data points for each sensor.
     */
    public SensorData(long timestamp, StringValueMap sensors) {
        super(timestamp);
        this.sensors = (sensors == null) ? new StringValueMap() : sensors;
    }

    /**
     * Constructor.
     * 
     * @param sensors
     *            - map containing data points for each sensor.
     */
    public SensorData(StringValueMap sensors) {
        super(DxcData.getCurrentTime());
        this.sensors = (sensors == null) ? new StringValueMap() : sensors;
    }

    /**
     * Returns the map from sensor to Value.
     * 
     * If the type of datapoint is unknown (it should be made known, for example
     * through an XML system catalog), the Value type for each point must be
     * determined by trial and error (using RTTI or dynamic_cast null tests).
     */
    public Map<String, Value> getSensorValueMap() {
        return sensors;
    }

    public OutputStream put(OutputStream os) {
        PrintStream out = new PrintStream(os);
        out.append("sensors @");
        out.append(Long.toString(this.getTimeStamp()));
        if (this.getSource() != null)
            out.append(" <" + this.getSource() + ">");

        out.append(" { ");

        boolean fg = false;
        Iterator<String> i = sensors.keySet().iterator();
        while (i.hasNext()) {
            String s = i.next();

            if (fg) {
                out.append(", ");
            } else {
                fg = true;
            }
            out.append(s + " = ");
            sensors.get(s).put(out);
        }
        out.append(" };\n");

        return out;
    }

    public boolean equals(Object o) {
        if (o == this)
            return true;
        if ((o == null) || (o.getClass() != this.getClass()))
            return false;

        SensorData sd = (SensorData) o;

        if ((sd.getTimeStamp() != getTimeStamp())
                || (!sd.getSource().equals(getSource()))
                || (!sd.getSensorValueMap().equals(getSensorValueMap())))
            return false;

        return true;
    }

    public int hashCode() {
        return ((int) getTimeStamp() * 31 + getSource().hashCode()) * 31
                + getSensorValueMap().hashCode();
    }
}