package org.dxc.evaluator.metrics;

import org.w3c.dom.Element;
import org.dxc.evaluator.XmlHelper;

/*
 * Evaluator metric information.
 */
public class MetricInfo {
    private String name;
    private String daMetricName;

    private double weight;
    private boolean higherBetter;
    private String printPrefix;
    private String printPostfix;

    private int minDataPoints;
    private String scenarioMetricName;

    public MetricInfo(String name, String daMetricName, double weight,
            boolean higherIsBetter, String printPrefix, String printPostfix,
            int minDataPoints, String scenarioMetricName) {
        this.setName(name);
        this.weight = weight;
        this.higherBetter = higherIsBetter;
        this.printPostfix = printPostfix;
        this.printPrefix = printPrefix;
        this.minDataPoints = minDataPoints;
        this.scenarioMetricName = scenarioMetricName;
        this.daMetricName = daMetricName;
    }

    public MetricInfo(Element item) {
        String name, prefx, postfx;
        double weight;
        int minDataPoints;
        boolean hib;

        name = item.getAttribute("name");
        try {
            daMetricName = item.getAttribute("daMetric");
            if (daMetricName == null || daMetricName.length() < 1)
                daMetricName = name;
        } catch (Exception ex) {
            daMetricName = name;
        }

        weight = Double.parseDouble(XmlHelper
                .getChildTextByName(item, "weight"));
        hib = Boolean.parseBoolean(XmlHelper.getChildTextByName(item,
                "higherIsBetter"));
        prefx = XmlHelper.getChildTextByName(item, "printPrefix") + " ";
        postfx = " " + XmlHelper.getChildTextByName(item, "printPostfix");

        scenarioMetricName = XmlHelper.getChildTextByName(item,
                "scenarioMetric");

        try {
            minDataPoints = Integer.parseInt(XmlHelper.getChildTextByName(item,
                    "minDataPoints"));
        } catch (Exception ex) {
            minDataPoints = -1;
        }

        this.name = name;
        this.weight = weight;
        this.higherBetter = hib;
        this.printPostfix = postfx;
        this.printPrefix = prefx;
        this.minDataPoints = minDataPoints;
    }

    public int getMinDataPoints() {
        return minDataPoints;
    }

    public void setMinDataPoints(int minDataPoints) {
        this.minDataPoints = minDataPoints;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getName() {
        return name;
    }

    public double getWeight() {
        return weight;
    }

    public void setWeight(double weight) {
        this.weight = weight;
    }

    public boolean isHigherBetter() {
        return higherBetter;
    }

    public void setHigherBetter(boolean higherIsBetter) {
        this.higherBetter = higherIsBetter;
    }

    public String getPrintPrefix() {
        return printPrefix;
    }

    public void setPrintPrefix(String printPrefix) {
        this.printPrefix = printPrefix;
    }

    public String getPrintPostfix() {
        return printPostfix;
    }

    public void setPrintPostfix(String printPostfix) {
        this.printPostfix = printPostfix;
    }

    public String getScenarioMetricName() {
        return scenarioMetricName;
    }

    public String getDAMetricName() {
        return daMetricName;
    }
}
