package org.dxc.evaluator.metrics;

import static org.junit.Assert.*;

import org.junit.Test;
import org.dxc.api.datatypes.*;

public class TestClassificationErrors {
    @Test
    public void defaultNaN() {
        ClassificationErrors ces = new ClassificationErrors();

        assertEquals("Score should be NaN by default", Double.NaN, ces
                .getScore(), 0.0001);
    }

    @Test
    public void classificationErrors() throws Exception {
        CandidateSet cs = new CandidateSet();
        ClassificationErrors ces = new ClassificationErrors();
        Candidate c1 = new Candidate(), c2 = new Candidate(), c3 = new Candidate();
        c1.getFaultSet().add(new Fault("a", "m1"));
        c1.getFaultSet().add(new Fault("b", "m2"));
        c1.setWeight(0.6);
        cs.add(c1);
        c2.getFaultSet().add(new Fault("c", "m1"));
        c2.setWeight(0.3);
        c3.setWeight(0.1);
        cs.add(c1);
        cs.add(c2);
        cs.add(c3);
        ces.addData(new FaultInjectData(0, new Fault("a", "m1"), true));
        ces.addData(new FaultInjectData(1, new Fault("c", "m1"), true));
        ces.addData(new DiagnosisData(7, true, true, cs, ""));

        ces.calculate();

        assertEquals(1.7, ces.getScore(), 0.00001);
    }

    @Test
    public void faultParameters() throws Exception {
        CandidateSet cs = new CandidateSet();
        ClassificationErrors ces = new ClassificationErrors();
        Candidate c1 = new Candidate();

        StringValueMap svm = new StringValueMap();
        svm.put("testParam", Value.v(2.0));

        c1.getFaultSet().add(new Fault("a", "m1", svm));
        c1.getFaultSet().add(new Fault("b", "m2"));
        cs.add(c1);
        ces.addData(new FaultInjectData(0, new Fault("a", "m1"), true));
        ces.addData(new FaultInjectData(1, new Fault("c", "m1"), true));
        ces.addData(new DiagnosisData(7, true, true, cs, ""));

        ces.calculate();

        assertEquals(2, ces.getScore(), 0.00001);
    }
}
