package org.dxc.evaluator.metrics;

import static org.junit.Assert.*;

import org.junit.Test;
import org.dxc.api.datatypes.*;

public class TestProbeCost {
    @Test
    public void defaultZero() {
        ProbeCost rc = new ProbeCost();

        assertEquals("Score should be zero by default", Double.NaN, rc
                .getScore(), 0.0001);
    }

    @Test
    public void multipleProbes() throws Exception {
        ProbeCost pc = new ProbeCost();
        pc.addData(new ScenarioStatusData(ScenarioStatusData.STARTED));
        pc.addData(new ScenarioData("", "74181", "", "", "", "", 10, ""));
        CommandSet cs = new CommandSet();
        cs.add(new Command("probe", Value.v("z2")));
        cs.add(new Command("probe", Value.v("z3")));
        cs.add(new Command("probe", Value.v("z50")));
        cs.add(new Command("probe", Value.v("z30")));
        cs.add(new Command("probe", Value.v("z27")));
        pc.addData(new CommandData(1000, cs));

        pc.calculate();

        // change expected cost to whatever it is in reality
        assertEquals(5, pc.getScore(), 0.00001);
    }

    @Test
    public void separateProbes() throws Exception {
        ProbeCost rc = new ProbeCost();
        rc.addData(new ScenarioStatusData(ScenarioStatusData.STARTED));
        rc.addData(new ScenarioData("", "74181", "", "", "", "", 10, ""));
        rc.addData(new CommandData(1000, "probe", Value.v("z2")));
        rc.addData(new CommandData(1001, "probe", Value.v("z20")));
        rc.addData(new CommandData(1002, "probe", Value.v("z32")));
        rc.addData(new CommandData(1003, "probe", Value.v("z50")));
        rc.addData(new CommandData(1004, "probe", Value.v("z18")));
        rc.addData(new CommandData(1005, "probe", Value.v("z1")));

        rc.calculate();

        // change expected cost to whatever it is in reality
        assertEquals(6, rc.getScore(), 0.00001);
    }
}
