package org.dxc.evaluator.metrics;

import static org.junit.Assert.*;

import org.junit.AfterClass;
import org.junit.Test;
import org.dxc.api.datatypes.*;

public class TestRecoveryCost {
    @Test
    public void defaultZero() {
        RecoveryCost rc = new RecoveryCost();

        assertEquals("Score should be zero by default", Double.NaN, rc
                .getScore(), 0.0001);
    }

    @Test
    public void abortCostAdaptLite() throws Exception {
        RecoveryCost rc = new RecoveryCost();
        rc.addData(new ScenarioStatusData(0, ScenarioStatusData.STARTED));
        rc.addData(new ScenarioData("", "ADAPT-Lite", "", "", "", "", 10, ""));
        StringValueMap pm = new StringValueMap();
        pm.put("Offset", new RealValue(-2.5));
        Fault f = new Fault("DC485", "ResistanceOffset", pm);
        rc.addData(new FaultInjectData(500, f, true));
        rc.addData(new CommandData(1000, "systemAction", new StringValue(
                "ABORT")));

        rc.calculate();

        // change expected cost to whatever it is in reality
        assertEquals(0, rc.getScore(), 0.00001);
    }

    @Test
    public void stringValue() throws Exception {
        RecoveryCost rc = new RecoveryCost();
        rc.addData(new ScenarioStatusData(0, ScenarioStatusData.STARTED));
        rc.addData(new ScenarioData("", "ADAPT-Lite", "", "", "", "", 10, ""));
        StringValueMap pm = new StringValueMap();
        pm.put("Offset", new StringValue(" -2.5"));
        Fault f = new Fault("DC485", "ResistanceOffset", pm);
        rc.addData(new FaultInjectData(500, f, true));
        rc.addData(new CommandData(1000, "systemAction", new StringValue(
                "ABORT")));

        rc.calculate();

        // change expected cost to whatever it is in reality
        assertEquals(0, rc.getScore(), 0.00001);
    }
    
    @Test
    public void loseVehicleCostAdaptLite() throws Exception {
        RecoveryCost rc = new RecoveryCost();
        rc.addData(new ScenarioStatusData(0, ScenarioStatusData.STARTED));
        rc.addData(new ScenarioData("", "ADAPT-Lite", "", "", "", "", 10, ""));
        // StringValueMap pm = new StringValueMap();
        // pm.put("Offset", new RealValue(-2.5));
        // Fault f = new Fault("DC485", "ResistanceOffset", pm);
        Fault f = new Fault("AC483", "FailedOff");
        rc.addData(new FaultInjectData(31000, f, true));
        rc.addData(new CommandData(33000, "systemAction",
                new StringValue("NOP")));

        rc.calculate();

        // change expected cost to whatever it is in reality
        assertEquals(125, rc.getScore(), 0.00001);
    }

    @Test
    public void missedCommandCostAdapt() throws Exception {
        RecoveryCost rc = new RecoveryCost();
        rc.addData(new ScenarioStatusData(0, ScenarioStatusData.STARTED));
        rc.addData(new ScenarioData("", "ADAPT", "", "", "", "", 240000, ""));
        sendSDSCommand(rc, 2407, "EY141_CL");
        sendSDSCommand(rc, 2438, "EY160_CL");
        sendSDSCommand(rc, 3641, "EY244_CL");
        sendSDSCommand(rc, 3672, "EY260_CL");
        sendSDSCommand(rc, 5047, "EY170_CL");
        sendSDSCommand(rc, 5750, "EY171_CL");
        sendSDSCommand(rc, 6891, "EY183_CL");
        sendSDSCommand(rc, 7750, "EY270_CL");
        sendSDSCommand(rc, 8500, "EY271_CL");

        Fault f = new Fault("EY170", "StuckOpen");
        rc.addData(new FaultInjectData(31000, f, true));
        rc.addData(new CommandData(33000, "systemAction",
                new StringValue("NOP")));

        rc.calculate();

        // change expected cost to whatever it is in reality
        assertEquals(125, rc.getScore(), 0.00001);
    }

    @Test
    public void stuckFault() throws Exception {
        RecoveryCost rc = new RecoveryCost();
        rc.addData(new ScenarioStatusData(0, ScenarioStatusData.STARTED));
        rc.addData(new ScenarioData("", "ADAPT", "", "", "", "", 240000, ""));
        sendSDSCommand(rc, 2407, "EY141_CL");
        sendSDSCommand(rc, 2438, "EY160_CL");
        sendSDSCommand(rc, 3641, "EY344_CL");
        sendSDSCommand(rc, 3672, "EY260_CL");
        sendSDSCommand(rc, 5047, "EY170_CL");
        sendSDSCommand(rc, 5750, "EY171_CL");
        sendSDSCommand(rc, 6891, "EY183_CL");
        sendSDSCommand(rc, 7750, "EY270_CL");
        sendSDSCommand(rc, 8500, "EY271_CL");

        StringValueMap pm = new StringValueMap();
        pm.put("StuckAt", Value.v(" 0.0"));
        Fault f = new Fault("E281", "Stuck", pm);
        rc.addData(new FaultInjectData(31000, f, true));

        rc.calculate();

        // change expected cost to whatever it is in reality
        assertEquals(0, rc.getScore(), 0.00001);
    }

    @Test
    public void wrongCommandCostAdapt() throws Exception {
        RecoveryCost rc = new RecoveryCost();
        rc.addData(new ScenarioStatusData(0, ScenarioStatusData.STARTED));
        rc.addData(new ScenarioData("", "ADAPT", "", "", "", "", 240000, ""));
        sendSDSCommand(rc, 2407, "EY141_CL");
        sendSDSCommand(rc, 2438, "EY160_CL");
        sendSDSCommand(rc, 3641, "EY244_CL");
        sendSDSCommand(rc, 3672, "EY260_CL");
        sendSDSCommand(rc, 5047, "EY170_CL");
        sendSDSCommand(rc, 5750, "EY171_CL");
        sendSDSCommand(rc, 6891, "EY183_CL");
        sendSDSCommand(rc, 7750, "EY270_CL");
        sendSDSCommand(rc, 8500, "EY271_CL");

        Fault f = new Fault("EY170", "StuckOpen");
        rc.addData(new FaultInjectData(31000, f, true));
        rc.addData(new CommandData(33000, "systemAction",
                new StringValue("NOP")));

        rc.calculate();

        // change expected cost to whatever it is in reality
        assertEquals(125, rc.getScore(), 0.00001);
    }

    void sendSDSCommand(ScenarioMetricCalculator s, long time, String cmd) {
        CommandData cd = new CommandData(time, cmd, Value.v(true));
        cd.setSource("SDS");
        s.addData(cd);
    }

    @AfterClass
    public static void shutDownOracle() {
        OracleInterface.shutdown();
    }
}
